@@ -13,7 +13,7 @@ public:
 	             choosebook_robutton,filling_robutton,know_robutton,wordedit_robutton,bookedit_robutton,sentence_robutton;
 	tPixButton exit_button;
 	GtkWidget *fixed, *wordlist_vscroll, *text_area, *text_label;
-	GtkObject *wordlist_adjust;
+	GtkAdjustment *wordlist_adjust;
 
 	CHelp ();
 	void init ();
