@@ -1,6 +1,6 @@
 /* ReciteWord - Recite Word Eassily
- * http://reciteword.cosoft.org.cn
- * Copyright (C) 2002-2007 Hu Zheng <huzheng_001@163.com>
+ * http://reciteword.sourceforge.net
+ * Copyright (C) 2002-2012 Hu Zheng <huzheng001@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,10 +17,10 @@
  */
 
 /*
- * Modified by the ReciteWord Team and others 2002-2003.  See the AUTHORS
+ * Modified by the ReciteWord Team and others 2002-2012.  See the AUTHORS
  * file for a list of people on the ReciteWord Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * ReciteWord at http://reciteword.cosoft.org.cn.
+ * ReciteWord at http://reciteword.sourceforge.net
  */
 
 
@@ -277,8 +277,9 @@ CReciteWord::ShowTyping ()
 static gboolean
 on_mainwnd_button_press (GtkWidget * window, GdkEventButton * event ,CReciteWord * parent)
 {
-	if (event->button == 1 && event->type == GDK_BUTTON_PRESS && event->window == parent->window->window && event->y < Skin->reciteword.titlebar_height)
+	if (event->button == 1 && event->type == GDK_BUTTON_PRESS && (event->y < Skin->reciteword.titlebar_height)) {
 		gtk_window_begin_move_drag(GTK_WINDOW(window),event->button,(gint)event->x_root,(gint)event->y_root,event->time);
+	}
 	return true;
 }
 
@@ -318,39 +319,39 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	gboolean only_ctrl_pressed = ((event->state & GDK_CONTROL_MASK)&&(!(event->state & GDK_MOD1_MASK))&&(!(event->state & GDK_SHIFT_MASK)));
 	gboolean only_mod1_pressed = ((event->state & GDK_MOD1_MASK)&&(!(event->state & GDK_CONTROL_MASK))&&(!(event->state & GDK_SHIFT_MASK)));
 	if ((event->type==GDK_KEY_PRESS)&&(
-			((event->keyval==GDK_q || event->keyval==GDK_Q) && only_ctrl_pressed)
-		|| ((event->keyval==GDK_x || event->keyval==GDK_X) && only_mod1_pressed)
-	//	|| (event->keyval==GDK_F4 && only_mod1_pressed) //this may not needed.
+			((event->keyval==GDK_KEY_q || event->keyval==GDK_KEY_Q) && only_ctrl_pressed)
+		|| ((event->keyval==GDK_KEY_x || event->keyval==GDK_KEY_X) && only_mod1_pressed)
+	//	|| (event->keyval==GDK_KEY_F4 && only_mod1_pressed) //this may not needed.
 	   ))
 	{
 		parent->close();
 	}
-	else if ((event->keyval==GDK_z || event->keyval==GDK_Z) && only_mod1_pressed)
+	else if ((event->keyval==GDK_KEY_z || event->keyval==GDK_KEY_Z) && only_mod1_pressed)
 	{
 		//gtk_widget_hide(parent->window); //this will make window be hide,need some method to get an event to show it again.
 		gtk_window_iconify(GTK_WINDOW(parent->window));
 	}
-	else if (event->keyval==GDK_F1 && only_ctrl_pressed)
+	else if (event->keyval==GDK_KEY_F1 && only_ctrl_pressed)
 	{
 		if (event->type==GDK_KEY_PRESS)
 			parent->help_button.do_clicked();
 	}
-	else if (event->keyval==GDK_F2 && only_ctrl_pressed)
+	else if (event->keyval==GDK_KEY_F2 && only_ctrl_pressed)
 	{
 		if (event->type==GDK_KEY_PRESS)
 			parent->record_button.do_clicked();
 	}
-	else if (event->keyval==GDK_F3 && only_ctrl_pressed)
+	else if (event->keyval==GDK_KEY_F3 && only_ctrl_pressed)
 	{
 		if (event->type==GDK_KEY_PRESS)
 			parent->option_button.do_clicked();
 	}
-	else if (event->keyval==GDK_F4 && only_ctrl_pressed)
+	else if (event->keyval==GDK_KEY_F4 && only_ctrl_pressed)
 	{
 		if (event->type==GDK_KEY_PRESS)
 			parent->dict_button.do_clicked();
 	}
-	else if (event->keyval==GDK_F5 && only_ctrl_pressed)
+	else if (event->keyval==GDK_KEY_F5 && only_ctrl_pressed)
 	{
 		if (event->type==GDK_KEY_PRESS)
 			parent->about_button.do_clicked();
@@ -360,49 +361,49 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->menu->close ();
 				break;
-			case GDK_1:
-			case GDK_c:
-			case GDK_C:
+			case GDK_KEY_1:
+			case GDK_KEY_c:
+			case GDK_KEY_C:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->menu->choosebook_button.do_clicked ();
 				break;
-			case GDK_2:
-			case GDK_f:
-			case GDK_F:
+			case GDK_KEY_2:
+			case GDK_KEY_f:
+			case GDK_KEY_F:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->menu->firstrecite_button.do_clicked ();
 				break;
-			case GDK_3:
-			case GDK_r:
-			case GDK_R:
+			case GDK_KEY_3:
+			case GDK_KEY_r:
+			case GDK_KEY_R:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->menu->revise_button.do_clicked ();
 				break;
-			case GDK_4:
-			case GDK_s:
-			case GDK_S:
+			case GDK_KEY_4:
+			case GDK_KEY_s:
+			case GDK_KEY_S:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->menu->shooting_button.do_clicked ();
 				break;
-			case GDK_5:
-			case GDK_t:
-			case GDK_T:
+			case GDK_KEY_5:
+			case GDK_KEY_t:
+			case GDK_KEY_T:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->menu->typing_button.do_clicked ();
 				break;
-			case GDK_6:
-			case GDK_e:
-			case GDK_E:
+			case GDK_KEY_6:
+			case GDK_KEY_e:
+			case GDK_KEY_E:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->menu->rest_button.do_clicked ();
 				break;
-			case GDK_7:
-			case GDK_w:
-			case GDK_W:
+			case GDK_KEY_7:
+			case GDK_KEY_w:
+			case GDK_KEY_W:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->menu->know_button.do_clicked ();
 				break;
@@ -418,19 +419,19 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 			// sometimes,for example,when using reciteword,gaim's chating window popuped,you press alt-Enter for Escape will close the chating window,
 			// then the Reciteword's window get focus again,and receive the GDK_Return or GDK_Escape key released event,it make
 			// reciteword returned,this is not good,so check if event->type is GDK_KEY_PRESS.
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->chooseword->cancel_button.do_clicked();
 				break;
-			case GDK_Return:
+			case GDK_KEY_Return:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->chooseword->ok_button.do_clicked();
 				break;
-			case GDK_Up:
+			case GDK_KEY_Up:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->chooseword->do_up();
 				break;
-			case GDK_Down:
+			case GDK_KEY_Down:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->chooseword->do_down();
 				break;
@@ -448,77 +449,77 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_F1:
+			case GDK_KEY_F1:
 				if (event->type==GDK_KEY_PRESS)
 					parent->help_button.do_clicked();
 				break;
-			case GDK_F2:
+			case GDK_KEY_F2:
 				if (event->type==GDK_KEY_PRESS)
 					parent->record_button.do_clicked();
 				break;
-			case GDK_F3:
+			case GDK_KEY_F3:
 				if (event->type==GDK_KEY_PRESS)
 					parent->option_button.do_clicked();
 				break;
-			case GDK_F4:
+			case GDK_KEY_F4:
 				if (event->type==GDK_KEY_PRESS)
 					parent->dict_button.do_clicked();
 				break;
-			case GDK_F5:
+			case GDK_KEY_F5:
 				if (event->type==GDK_KEY_PRESS)
 					parent->about_button.do_clicked();
 				break;
-			case GDK_1:
-			case GDK_c:
-			case GDK_C:
+			case GDK_KEY_1:
+			case GDK_KEY_c:
+			case GDK_KEY_C:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->ShowChoosebook ();
 				else
 					return_val=false;
 				break;
-			case GDK_2:
-			case GDK_f:
-			case GDK_F:
+			case GDK_KEY_2:
+			case GDK_KEY_f:
+			case GDK_KEY_F:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->ShowFirstRecite_group ();
 				else
 					return_val=false;
 				break;
-			case GDK_3:
-			case GDK_r:
-			case GDK_R:
+			case GDK_KEY_3:
+			case GDK_KEY_r:
+			case GDK_KEY_R:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->ShowRevise_group ();
 				else
 					return_val=false;
 				break;
-			case GDK_4:
-			case GDK_s:
-			case GDK_S:
+			case GDK_KEY_4:
+			case GDK_KEY_s:
+			case GDK_KEY_S:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->ShowShooting ();
 				else
 					return_val=false;
 				break;
-			case GDK_5:
-			case GDK_t:
-			case GDK_T:
+			case GDK_KEY_5:
+			case GDK_KEY_t:
+			case GDK_KEY_T:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->ShowTyping ();
 				else
 					return_val=false;
 				break;
-			case GDK_6:
-			case GDK_e:
-			case GDK_E:
+			case GDK_KEY_6:
+			case GDK_KEY_e:
+			case GDK_KEY_E:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->ShowRest ();
 				else
 					return_val=false;
 				break;
-			case GDK_7:
-			case GDK_w:
-			case GDK_W:
+			case GDK_KEY_7:
+			case GDK_KEY_w:
+			case GDK_KEY_W:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->ShowKnow ();
 				else
@@ -534,11 +535,11 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Return:
+			case GDK_KEY_Return:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->choosebook->ok_button.do_clicked ();
 				break;
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->choosebook->return_button.do_clicked ();
 				break;
@@ -552,16 +553,16 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Return:
+			case GDK_KEY_Return:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_group->ok_button.do_clicked ();
 				break;
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_group->return_button.do_clicked ();
 				break;
-			/*case GDK_u:
-			case GDK_U:
+			/*case GDK_KEY_u:
+			case GDK_KEY_U:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -569,19 +570,19 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 					else  // GDK_KEY_RELEASE
 						g_pReciteWord->firstrecite_group->order_ckbutton.do_released ();
 				}*/
-			case GDK_Up:
+			case GDK_KEY_Up:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_group->do_up();
 				break;
-			case GDK_Down:
+			case GDK_KEY_Down:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_group->do_down();
 				break;
-			case GDK_Page_Up:
+			case GDK_KEY_Page_Up:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_group->do_pageup();
 				break;
-			case GDK_Page_Down:
+			case GDK_KEY_Page_Down:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_group->do_pagedown();
 				break;
@@ -595,7 +596,7 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Return:
+			case GDK_KEY_Return:
 				if (g_pReciteWord->firstrecite_skim->dialog.fixed)  //dialog is shown
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -609,15 +610,15 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 						return_val=false;
 				}
 				break;				
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_skim->return_button.do_clicked ();
 				break;
-			case GDK_Tab:
+			case GDK_KEY_Tab:
 				if (event->type==GDK_KEY_RELEASE)
 					g_pReciteWord->firstrecite_skim->readword_button.do_clicked (false);
 				break;
-			case GDK_Up:
+			case GDK_KEY_Up:
 				if (event->type==GDK_KEY_PRESS)
 				{
 					if (g_pReciteWord->firstrecite_skim->dialog.fixed)
@@ -628,7 +629,7 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 						g_pReciteWord->firstrecite_skim->do_up();
 				}
 				break;
-			case GDK_Down:
+			case GDK_KEY_Down:
 				if (event->type==GDK_KEY_PRESS)
 				{
 					if (g_pReciteWord->firstrecite_skim->dialog.fixed)
@@ -639,7 +640,7 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 						g_pReciteWord->firstrecite_skim->do_down();
 				}
 				break;
-			case GDK_space:
+			case GDK_KEY_space:
 				if (g_pReciteWord->firstrecite_skim->dialog.fixed)  //dialog is shown
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -651,32 +652,32 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 						g_pReciteWord->firstrecite_skim->do_down();
 				}
 				break;
-			case GDK_Left:
+			case GDK_KEY_Left:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_skim->do_left();
 				break;
-			case GDK_Right:
+			case GDK_KEY_Right:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_skim->do_right();
 				break;
-			case GDK_Page_Up:
+			case GDK_KEY_Page_Up:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_skim->do_pageup();
 				break;
-			case GDK_Page_Down:
+			case GDK_KEY_Page_Down:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_skim->do_pagedown();
 				break;
-			case GDK_Home:
+			case GDK_KEY_Home:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_skim->do_home();
 				break;
-			case GDK_End:
+			case GDK_KEY_End:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_skim->do_end();
 				break;
-			case GDK_s:
-			case GDK_S:
+			case GDK_KEY_s:
+			case GDK_KEY_S:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -685,13 +686,13 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Pause:
+			case GDK_KEY_Pause:
 				if (event->type==GDK_KEY_PRESS)
 						g_pReciteWord->firstrecite_skim->pause_button.do_clicked ();
 				else
 					return_val=false;
-			case GDK_p:
-			case GDK_P:
+			case GDK_KEY_p:
+			case GDK_KEY_P:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -700,15 +701,15 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_g:
-			case GDK_G:
+			case GDK_KEY_g:
+			case GDK_KEY_G:
 				if (only_ctrl_pressed)
 					g_pReciteWord->firstrecite_skim->group_button.do_clicked ();
 				else
 					return_val=false;
 				break;
-			case GDK_t:
-			case GDK_T:
+			case GDK_KEY_t:
+			case GDK_KEY_T:
 				if (only_ctrl_pressed)
 					g_pReciteWord->firstrecite_skim->test_button.do_clicked ();
 				else
@@ -725,8 +726,8 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Return:
-			case GDK_space:
+			case GDK_KEY_Return:
+			case GDK_KEY_space:
 				if (g_pReciteWord->firstrecite_test->dialog.fixed)  //dialog is shown
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -735,15 +736,15 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_test->return_button.do_clicked ();
 				break;
-			case GDK_Tab:
+			case GDK_KEY_Tab:
 				if (event->type==GDK_KEY_RELEASE)
 					g_pReciteWord->firstrecite_test->readword_button.do_clicked (false);
 				break;
-			case GDK_Up:
+			case GDK_KEY_Up:
 				if (event->type==GDK_KEY_PRESS)
 				{
 					if (g_pReciteWord->firstrecite_test->dialog.fixed)
@@ -754,7 +755,7 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 						g_pReciteWord->firstrecite_test->do_up();
 				}
 				break;
-			case GDK_Down:
+			case GDK_KEY_Down:
 				if (event->type==GDK_KEY_PRESS)
 				{
 					if (g_pReciteWord->firstrecite_test->dialog.fixed)
@@ -765,16 +766,16 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 						g_pReciteWord->firstrecite_test->do_down();
 				}
 				break;
-			case GDK_Page_Up:
+			case GDK_KEY_Page_Up:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_test->do_pageup();
 				break;
-			case GDK_Page_Down:
+			case GDK_KEY_Page_Down:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->firstrecite_test->do_pagedown();
 				break;
-			case GDK_s:
-			case GDK_S:
+			case GDK_KEY_s:
+			case GDK_KEY_S:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -783,13 +784,13 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Pause:
+			case GDK_KEY_Pause:
 				if (event->type==GDK_KEY_PRESS)
 						g_pReciteWord->firstrecite_test->pause_button.do_clicked ();
 				else
 					return_val=false;
-			case GDK_p:
-			case GDK_P:
+			case GDK_KEY_p:
+			case GDK_KEY_P:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -798,15 +799,15 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_g:
-			case GDK_G:
+			case GDK_KEY_g:
+			case GDK_KEY_G:
 				if (only_ctrl_pressed)
 					g_pReciteWord->firstrecite_test->group_button.do_clicked ();
 				else
 					return_val=false;
 				break;
-			case GDK_b:
-			case GDK_B:
+			case GDK_KEY_b:
+			case GDK_KEY_B:
 				if (only_ctrl_pressed)
 					g_pReciteWord->firstrecite_test->skim_button.do_clicked ();
 				else
@@ -822,12 +823,12 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->revise_group->return_button.do_clicked ();
 				break;
-			case GDK_w:
-			case GDK_W:
+			case GDK_KEY_w:
+			case GDK_KEY_W:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -836,36 +837,36 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Return:
-			case GDK_F1:
+			case GDK_KEY_Return:
+			case GDK_KEY_F1:
 				if (event->type==GDK_KEY_PRESS)
 				{
 					if (g_pReciteWord->revise_group->plane[0])
 						g_pReciteWord->revise_group->plane[0]->do_clicked ();
 				}
 				break;
-			case GDK_F2:
+			case GDK_KEY_F2:
 				if (event->type==GDK_KEY_PRESS)
 				{
 					if (g_pReciteWord->revise_group->plane[1])
 						g_pReciteWord->revise_group->plane[1]->do_clicked ();
 				}
 				break;
-			case GDK_F3:
+			case GDK_KEY_F3:
 				if (event->type==GDK_KEY_PRESS)
 				{
 					if (g_pReciteWord->revise_group->plane[2])
 						g_pReciteWord->revise_group->plane[2]->do_clicked ();
 				}
 				break;
-			case GDK_F4:
+			case GDK_KEY_F4:
 				if (event->type==GDK_KEY_PRESS)
 				{
 					if (g_pReciteWord->revise_group->plane[3])
 						g_pReciteWord->revise_group->plane[3]->do_clicked ();
 				}
 				break;
-			case GDK_F5:
+			case GDK_KEY_F5:
 				if (event->type==GDK_KEY_PRESS)
 				{
 					if (g_pReciteWord->revise_group->plane[4])
@@ -882,8 +883,8 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{		
 		switch (event->keyval)
 		{
-			case GDK_Return:
-			case GDK_space:
+			case GDK_KEY_Return:
+			case GDK_KEY_space:
 				if (g_pReciteWord->revise_test->dialog.fixed)  //dialog is shown
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -897,16 +898,16 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->revise_test->return_button.do_clicked ();
 				break;
-			case GDK_Tab:
+			case GDK_KEY_Tab:
 				if (event->type==GDK_KEY_RELEASE)
 					g_pReciteWord->revise_test->readword_button.do_clicked (false);
 				break;
-			case GDK_w:
-			case GDK_W:
+			case GDK_KEY_w:
+			case GDK_KEY_W:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -915,10 +916,10 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_F12:
+			case GDK_KEY_F12:
 				g_pReciteWord->revise_test->handinpaper_button.do_clicked ();
 				break;
-			case GDK_Up:
+			case GDK_KEY_Up:
 				if (g_pReciteWord->revise_test->dialog.fixed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -927,7 +928,7 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;				
 				break;
-			case GDK_Down:
+			case GDK_KEY_Down:
 				if (g_pReciteWord->revise_test->dialog.fixed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -936,8 +937,8 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_s:
-			case GDK_S:
+			case GDK_KEY_s:
+			case GDK_KEY_S:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -946,13 +947,13 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Pause:
+			case GDK_KEY_Pause:
 				if (event->type==GDK_KEY_PRESS)
 						g_pReciteWord->revise_test->pause_button.do_clicked ();
 				else
 					return_val=false;
-			case GDK_p:
-			case GDK_P:
+			case GDK_KEY_p:
+			case GDK_KEY_P:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -961,15 +962,15 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_c:
-			case GDK_C:
+			case GDK_KEY_c:
+			case GDK_KEY_C:
 				if (only_ctrl_pressed)
 					g_pReciteWord->revise_test->group_button.do_clicked ();
 				else
 					return_val=false;
 				break;
-			case GDK_r:
-			case GDK_R:
+			case GDK_KEY_r:
+			case GDK_KEY_R:
 				if (only_ctrl_pressed)
 					g_pReciteWord->revise_test->skim_button.do_clicked ();
 				else
@@ -985,16 +986,16 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->revise_skim->return_button.do_clicked ();
 				break;
-			case GDK_Tab:
+			case GDK_KEY_Tab:
 				if (event->type==GDK_KEY_RELEASE)
 					g_pReciteWord->revise_skim->readword_button.do_clicked (false);
 				break;
-			case GDK_w:
-			case GDK_W:
+			case GDK_KEY_w:
+			case GDK_KEY_W:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1003,8 +1004,8 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_s:
-			case GDK_S:
+			case GDK_KEY_s:
+			case GDK_KEY_S:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1013,14 +1014,14 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Return:
-			case GDK_Pause:
+			case GDK_KEY_Return:
+			case GDK_KEY_Pause:
 				if (event->type==GDK_KEY_PRESS)
 						g_pReciteWord->revise_skim->pause_button.do_clicked ();
 				else
 					return_val=false;
-			case GDK_p:
-			case GDK_P:
+			case GDK_KEY_p:
+			case GDK_KEY_P:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1029,15 +1030,15 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_c:
-			case GDK_C:
+			case GDK_KEY_c:
+			case GDK_KEY_C:
 				if (only_ctrl_pressed)
 					g_pReciteWord->revise_skim->group_button.do_clicked ();
 				else
 					return_val=false;
 				break;
-			case GDK_b:
-			case GDK_B:
+			case GDK_KEY_b:
+			case GDK_KEY_B:
 				if (only_ctrl_pressed)
 					g_pReciteWord->revise_skim->test_button.do_clicked ();
 				else
@@ -1053,16 +1054,16 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->shooting->return_button.do_clicked ();
 				break;
-			case GDK_Tab:
+			case GDK_KEY_Tab:
 				if (event->type==GDK_KEY_RELEASE)
 					g_pReciteWord->shooting->readword_button.do_clicked (false);
 				break;
-			case GDK_w:
-			case GDK_W:
+			case GDK_KEY_w:
+			case GDK_KEY_W:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1071,30 +1072,30 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Up:
-			case GDK_Left:
+			case GDK_KEY_Up:
+			case GDK_KEY_Left:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->shooting->do_up();
 				break;
-			case GDK_Down:
-			case GDK_Right:
+			case GDK_KEY_Down:
+			case GDK_KEY_Right:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->shooting->do_down();
 				break;
-			case GDK_Page_Up:
+			case GDK_KEY_Page_Up:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->shooting->do_pageup();
 				break;
-			case GDK_Page_Down:
+			case GDK_KEY_Page_Down:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->shooting->do_pagedown();
 				break;
-			case GDK_Return:
+			case GDK_KEY_Return:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->shooting->do_fire();
 				break;
-			case GDK_s:
-			case GDK_S:
+			case GDK_KEY_s:
+			case GDK_KEY_S:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1103,13 +1104,13 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Pause:
+			case GDK_KEY_Pause:
 				if (event->type==GDK_KEY_PRESS)
 						g_pReciteWord->shooting->pause_button.do_clicked ();
 				else
 					return_val=false;
-			case GDK_p:
-			case GDK_P:
+			case GDK_KEY_p:
+			case GDK_KEY_P:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1128,12 +1129,12 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->typing->return_button.do_clicked ();
 				break;
-			case GDK_Return:
-			case GDK_space:
+			case GDK_KEY_Return:
+			case GDK_KEY_space:
 				if (g_pReciteWord->mark && g_pReciteWord->mark->fixed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1142,12 +1143,12 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Tab:
+			case GDK_KEY_Tab:
 				if (event->type==GDK_KEY_RELEASE)
 					g_pReciteWord->typing->readword_button.do_clicked (false);
 				break;
-			case GDK_w:
-			case GDK_W:
+			case GDK_KEY_w:
+			case GDK_KEY_W:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1156,8 +1157,8 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_s:
-			case GDK_S:
+			case GDK_KEY_s:
+			case GDK_KEY_S:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1166,13 +1167,13 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Pause:
+			case GDK_KEY_Pause:
 				if (event->type==GDK_KEY_PRESS)
 						g_pReciteWord->typing->pause_button.do_clicked ();
 				else
 					return_val=false;
-			case GDK_p:
-			case GDK_P:
+			case GDK_KEY_p:
+			case GDK_KEY_P:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1191,12 +1192,12 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->rest->return_button.do_clicked ();
 				break;
-			case GDK_s:
-			case GDK_S:
+			case GDK_KEY_s:
+			case GDK_KEY_S:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1205,13 +1206,13 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 				else
 					return_val=false;
 				break;
-			case GDK_Pause:
+			case GDK_KEY_Pause:
 				if (event->type==GDK_KEY_PRESS)
 						g_pReciteWord->rest->pause_button.do_clicked ();
 				else
 					return_val=false;
-			case GDK_p:
-			case GDK_P:
+			case GDK_KEY_p:
+			case GDK_KEY_P:
 				if (only_ctrl_pressed)
 				{
 					if (event->type==GDK_KEY_PRESS)
@@ -1230,7 +1231,7 @@ on_mainwnd_key_press_release (GtkWidget * window, GdkEventKey * event ,CReciteWo
 	{
 		switch (event->keyval)
 		{
-			case GDK_Escape:
+			case GDK_KEY_Escape:
 				if (event->type==GDK_KEY_PRESS)
 					g_pReciteWord->know->return_button.do_clicked ();
 				break;
@@ -1369,16 +1370,8 @@ void
 CReciteWord::create ()
 {
 	init ();
-//	gtk_widget_push_visual (gdk_rgb_get_visual ());
-//	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-//	gtk_widget_pop_visual ();
-//	gtk_widget_pop_colormap ();
-#ifdef G_OS_WIN32
 	gtk_widget_set_events(window,GDK_SCROLL_MASK | GDK_BUTTON_PRESS_MASK);
-#else
-	gtk_widget_set_events(window,GDK_SCROLL_MASK);
-#endif
 	gtk_window_set_decorated (GTK_WINDOW (window), FALSE);
 	gtk_widget_set_app_paintable(window,TRUE);
 	gtk_window_set_resizable(GTK_WINDOW(window),FALSE);
@@ -1406,13 +1399,10 @@ skin_load_chooseword (window);
 */
 	gtk_window_set_icon (GTK_WINDOW(window),Skin->face.icon.p[0]);
 	
-	tooltips = gtk_tooltips_new ();
-	
 	fixed = gtk_fixed_new ();
-	//gtk_fixed_set_has_window(GTK_FIXED(fixed),TRUE);
+	//gtk_widget_set_has_window(fixed,TRUE);
 	gtk_container_add (GTK_CONTAINER (window), fixed);
 	gtk_widget_show (fixed);
-	SetBackPixmap (fixed, Skin->face.face.p[0]);
 
 	help_button.create (fixed, Skin->face.help_button.x[0],
 			    Skin->face.help_button.y[0], Skin->face.help_button.p[0],
@@ -1441,7 +1431,7 @@ skin_load_chooseword (window);
 	GtkWidget *event_box = gtk_event_box_new ();
 	gtk_fixed_put (GTK_FIXED (fixed), event_box, Skin->face.menubar.x[0],
 		       Skin->face.menubar.y[0]);
-	GtkWidget *pixmap_widget = gtk_image_new_from_pixmap (Skin->face.menubar.p[0], NULL);
+	GtkWidget *pixmap_widget = gtk_image_new_from_pixbuf (Skin->face.menubar.p[0]);
 	gtk_container_add (GTK_CONTAINER (event_box), pixmap_widget);
 	gtk_widget_show (pixmap_widget);
 	gtk_widget_show (event_box);
@@ -1462,9 +1452,8 @@ skin_load_chooseword (window);
 	g_signal_connect (G_OBJECT (window), "delete_event",
 			  G_CALLBACK (on_mainwnd_delete_event), this);
 	gtk_widget_show (window);
-	gdk_threads_enter();
+	SetBackPixmap (fixed, Skin->face.face.p[0]);
 	gtk_main ();
-	gdk_threads_leave();
 }
 
 void
@@ -1558,7 +1547,8 @@ CReciteWord::destroy ()
 void
 CReciteWord::close ()
 {
-	destroy ();
+	destroy();
+	Skin->destroy();
 
 	if (now_zu_words.w)
 	{
@@ -1588,7 +1578,7 @@ CReciteWord::close ()
 }
 
 void
-CReciteWord::set_now_zu_words(gint zu_index,gint zu_wordcount,gchar **zu_words_w,gchar **zu_words_t,gchar **zu_words_m,gboolean disorder)
+CReciteWord::set_now_zu_words(gint zu_index,gint zu_wordcount, gchar **zu_words_w, gchar **zu_words_t, gchar **zu_words_m,gboolean disorder)
 {
 	now_zu_index =zu_index;
 	now_zu_wordcount =zu_wordcount;
@@ -1811,9 +1801,8 @@ int main(int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 	g_thread_init(NULL);
-	gtk_set_locale ();
 #ifdef G_OS_WIN32
-    gtk_init (&_argc, &_argv);
+	gtk_init (&_argc, &_argv);
 
 	/* We don't want a console window.. */
 	/*
@@ -1886,6 +1875,8 @@ int main(int argc, char *argv[])
 		delete g_pReciteWord;
 		return 0;
 	}
+	g_pReciteWord->sndserv.init();
+	g_pReciteWord->wyabdc.init();
 	if (onlyshowdict)
 	{
 		g_pReciteWord->dict_window = new CDict;
